summaryrefslogtreecommitdiff
path: root/scripts/mysqld_multi.sh
diff options
context:
space:
mode:
authorRucha Deodhar <rucha.deodhar@mariadb.com>2021-02-08 14:52:04 +0530
committerRucha Deodhar <rucha.deodhar@mariadb.com>2021-06-14 15:10:47 +0530
commit193bfdd831bbbf65e74acd12baf691d4305e3c11 (patch)
tree1bc2114e18e591571745d45a0d22f9c569b26c16 /scripts/mysqld_multi.sh
parentcb0cad8156f5c7de3777e465a6b8f64bc440b278 (diff)
downloadmariadb-git-193bfdd831bbbf65e74acd12baf691d4305e3c11.tar.gz
MDEV-22010: use executables MariaDB named in scripts
As a part of this MDEV following changes were made: 1) Mariadb named executables used instead of mysql named executables in scripts 2) renamed mysql-test-run and mysql-stress-test to mariadb-test-run and mariadb-stress-test and created a symlink.
Diffstat (limited to 'scripts/mysqld_multi.sh')
-rw-r--r--scripts/mysqld_multi.sh32
1 files changed, 16 insertions, 16 deletions
diff --git a/scripts/mysqld_multi.sh b/scripts/mysqld_multi.sh
index 77ed36218d3..51cb052bde0 100644
--- a/scripts/mysqld_multi.sh
+++ b/scripts/mysqld_multi.sh
@@ -29,8 +29,8 @@ my @defaults_options; # Leading --no-defaults, --defaults-file, etc.
$opt_example = 0;
$opt_help = 0;
$opt_log = undef();
-$opt_mysqladmin = "@bindir@/mysqladmin";
-$opt_mysqld = "@sbindir@/mysqld";
+$opt_mysqladmin = "@bindir@/mariadb-admin";
+$opt_mysqld = "@sbindir@/mariadbd";
$opt_no_log = 0;
$opt_password = undef();
$opt_tcp_ip = 0;
@@ -360,9 +360,9 @@ sub start_mysqlds()
$tmp.= " $options[$j]";
}
}
- if ($opt_verbose && $com =~ m/\/(safe_mysqld|mysqld_safe)$/ && !$info_sent)
+ if ($opt_verbose && $com =~ m/\/(mariadbd-safe)$/ && !$info_sent)
{
- print "WARNING: $1 is being used to start mysqld. In this case you ";
+ print "WARNING: $1 is being used to start mariadbd. In this case you ";
print "may need to pass\n\"ledir=...\" under groups [mysqldN] to ";
print "$1 in order to find the actual mysqld binary.\n";
print "ledir (library executable directory) should be the path to the ";
@@ -680,14 +680,14 @@ sub example
#
# 2.PID-FILE
#
# If you are using mysqld_safe to start mysqld, make sure that every
# MariaDB server has a separate pid-file. In order to use mysqld_safe
# via $my_progname, you need to use two options:
#
-# mysqld=/path/to/mysqld_safe
-# ledir=/path/to/mysqld-binary/
+# mysqld=/path/to/mariadbd-safe
+# ledir=/path/to/mariadbd-binary/
#
# ledir (library executable directory), is an option that only mysqld_safe
# accepts, so you will get an error if you try to pass it to mysqld directly.
# For this reason you might want to use the above options within [mysqld#]
# group directly.
@@ -740,8 +740,8 @@ sub example
#
[mysqld_multi]
-mysqld = @bindir@/mysqld_safe
-mysqladmin = @bindir@/mysqladmin
+mysqld = @bindir@/mariadbd-safe
+mysqladmin = @bindir@/mariadb-admin
user = multi_admin
password = my_password
@@ -754,9 +754,9 @@ language = @datadir@/mysql/english
user = unix_user1
[mysqld3]
-mysqld = /path/to/mysqld_safe
-ledir = /path/to/mysqld-binary/
-mysqladmin = /path/to/mysqladmin
+mysqld = /path/to/mariadbd-safe
+ledir = /path/to/mariadbd-binary/
+mysqladmin = /path/to/mariadb-admin
socket = /tmp/mysql.sock3
port = 3308
pid-file = @localstatedir@3/hostname.pid3
@@ -841,9 +841,9 @@ Using: @{[join ' ', @defaults_options]}
--mysqladmin=... mysqladmin binary to be used for a server shutdown.
Since version 2.10 this can be given within groups [mysqld#]
Using: $mysqladmin
---mysqld=... mysqld binary to be used. Note that you can give mysqld_safe
+--mysqld=... mariadbd binary to be used. Note that you can give mariadbd-safe
to this option also. The options are passed to mysqld. Just
- make sure you have mysqld in your PATH or fix mysqld_safe.
+ make sure you have mariadbd in your PATH or fix mariadbd-safe.
Using: $mysqld
Please note: Since mysqld_multi version 2.3 you can also
give this option inside groups [mysqld#] in ~/.my.cnf,
@@ -680,14 +680,14 @@ sub example
# 2.PID-FILE
#
-# If you are using mysqld_safe to start mysqld, make sure that every
-# MariaDB server has a separate pid-file. In order to use mysqld_safe
+# If you are using mariadbd-safe to start mariadbd, make sure that every
+# MariaDB server has a separate pid-file. In order to use mariadbd-safe
# via $my_progname, you need to use two options:
#
@@ -680,14 +680,14 @@ sub example
#
-# ledir (library executable directory), is an option that only mysqld_safe
+# ledir (library executable directory), is an option that only mariadbd-safe
# accepts, so you will get an error if you try to pass it to mysqld directly.
# For this reason you might want to use the above options within [mysqld#]